@@ -9,6 +9,8 @@ import shutil
 import glob
 import codecs
 import re
+import sys
+import traceback
 
 from .tools import *
 from .log import logger
@@ -532,13 +534,23 @@ class Package(object):
         )
 
     def save(self, filename):
+        #add for python2.7 change sys encoding to UTF-8
+        python_version = sys.version_info[0]
+        print(python_version)
+        if(python_version == 2):
+            print("python2.7 need change sys encoding to utf-8")
+            reload(sys)
+            sys.setdefaultencoding("utf-8")
+        #python3 default encode utf-8
+
         text = self.dumps()
         try:
-            with codecs.open(filename or self.filename, 'w', 'UTF-8') as f:
+            with codecs.open(filename or self.filename, 'w', encoding = 'utf-8') as f:
                 f.write(text)
             return True
         except:
             put_string("Generate %s file failed." % self.filename)
+            traceback.print_exc()
 
     def text_out(self, k, v, desc=''):
         k_len = len(k)
