@@ -215,7 +215,7 @@ class Solution:
             if component.need_build:
                 components.add(component)
         self.components = components
-
+ 
         def cpu_set_variable(cpu, arch):
             def gen_cpu_defs(cpu):
                 c = cpu.upper()
@@ -241,6 +241,9 @@ class Solution:
             elif arch.upper() == 'XTENSA':
                 self.variables.set('cpu_num', 'esp32')
                 self.variables.set('ARCH', arch, True)
+            elif arch.upper() == 'MIPS':
+                self.variables.set('cpu_num', mips_cpu_id(cpu))
+                self.variables.set('ARCH', arch, True)
             else:
                 logger.error("not support arch:%s yet" % arch)
                 exit(-1)
@@ -513,6 +516,7 @@ class Solution:
                         self.defines['__AOS_' + k + '__'] = v
 
         update_variables()
+
         if self.solution_component.separate_app:
             add_define('AOS_SEPARATE_APP', 1)
         def check_variable(values=[]):
@@ -649,3 +653,11 @@ def riscv_cpu_id(cpu):
     else:
         put_string("%s not support yet." % a)
         exit(0)
+
+def mips_cpu_id(cpu):
+    a = cpu.lower()
+    if a == 'ls232':
+        return 'ls232'
+    else:
+        put_string("%s not support yet." % a)
+        exit(0)
