@@ -137,13 +137,15 @@ Make aos program.\n"
             print(filename)
             print(solutionName)
 
+            # add app_board to package.yaml file
             if os.path.isfile(filename):
                 pack = Package(filename)
                 for d in pack.depends:
                     if pack.hw_info.board_name in d:
                         pack.depends.remove(d)
-                    l = str(d).replace("}","").replace("'","").split(":")
-                depend = {app_board: l[1]}
+
+                str_version = pack.version
+                depend = {app_board: str_version}
                 pack.depends.append(depend)
                 pack.hw_info.board_name = app_board
                 pack.save(filename)
@@ -173,8 +175,9 @@ Make aos program.\n"
                 for d in pack.depends:
                     if pack.hw_info.board_name in d:
                         pack.depends.remove(d)
-                    l = str(d).replace("}","").replace("'","").split(":")
-                depend = {v[1]: l[1]}
+
+                str_version = pack.version
+                depend = {v[1]: str_version}
                 pack.depends.append(depend)
                 pack.hw_info.board_name = v[1]
                 pack.save(filename)
