@@ -58,6 +58,7 @@ all_toolchain_url = {
 class ToolchainYoC:
     def __init__(self):
         self.basepath = home_path('.aliot')
+        self.espbasepath = home_path('.espressif')
 
     def download(self, arch):
         toolchain_path = os.path.join(self.basepath, arch)
@@ -135,6 +136,10 @@ class ToolchainYoC:
         else:
             print('use user settings toolchain path!!')
 
+        # check esp32 dependency tool
+        tool_path = self.check_esp32_dependency(arch)
+        self.download_esp32_dependency_tool(tool_path)
+
         return bin_file
 
     def check_toolchain_by_path(self, arch='csky-abiv2-elf', tool_path=''):
@@ -153,6 +158,50 @@ class ToolchainYoC:
                         path = which(path)
         return path
 
+
+    def check_esp32_dependency(self, arch='csky-abiv2-elf'):
+        """ check PATH, ~/.espressif/dist/"""
+        dependTool = []
+        toolPath = os.path.join(self.espbasepath, "dist")
+        if arch.startswith('riscv32-esp-elf'):
+            tool = 'xtensa-esp32s2-elf-gcc8_4_0-esp-2021r2-linux-amd64.tar.gz'
+            dependToolPath = os.path.join(toolPath, tool)
+            if os.path.exists(dependToolPath):
+                tool = ''
+            else:
+                dependTool.append(tool)
+
+            tool = 'xtensa-esp32s3-elf-gcc8_4_0-esp-2021r2-linux-amd64.tar.gz'
+            dependToolPath = os.path.join(toolPath, tool)
+            if os.path.exists(dependToolPath):
+                tool = ''
+            else:
+                dependTool.append(tool)
+
+        if arch.startswith('xtensa-esp32-elf'):
+            tool = 'xtensa-esp32s2-elf-gcc8_4_0-esp-2020r3-linux-amd64.tar.gz'
+            dependToolPath = os.path.join(toolPath, tool)
+            if os.path.exists(dependToolPath):
+                tool = ''
+            else:
+                dependTool.append(tool)
+
+        return dependTool
+
+    def download_esp32_dependency_tool(self, tool=[]):
+        if tool == []:
+            return
+        else:
+            for item in tool:
+                toolPath = os.path.join(self.espbasepath, "dist", item)
+                dependTool_url = 'https://hli.aliyuncs.com/o/config/esp32_toolchain/' + item
+                print("down load esp32 dependency tool")
+                print(dependTool_url)
+                wget(dependTool_url, toolPath)
+
+        return
+
+
     def check_program(self, arch='csky-abiv2-elf'):
         """ check PATH, ~/.aliot/<arch>/bin,  ~/.aliot/<arch>/main/bin"""
         path = which(arch + '-gcc')
